@@ -7,13 +7,7 @@ from .sublist3r import sublist3r
 from .sherlock import sherlock
 from .s3scanner import s3scanner
 
-__tools__ = {
-    "nmap": nmap,
-    "sqlmap": sqlmap,
-    "sublist3r": sublist3r,
-    "sherlock": sherlock,
-    "s3scanner": s3scanner
-}
+__tools__ = [nmap, sqlmap, sublist3r, sherlock, s3scanner]
 
 
 def cli():
