@@ -4,8 +4,10 @@ from fsociety.core.repo import GitHubRepo
 
 
 class hashBusterRepo(GitHubRepo):
-    def __init__(self, path="s0md3v/Hash-Buster", install=None):
-        super().__init__(path=path, install=install)
+    def __init__(self):
+        super().__init__(path="s0md3v/Hash-Buster",
+                         install=None,
+                         description="Why crack hashes when you can bust them?")
 
     def run(self):
         os.chdir(self.full_path)
